@@ -8,9 +8,9 @@ __docformat__ = 'restructuredtext en'
 
 import os
 
-
 from sphinx.builders.latex import LaTeXBuilder
 
+
 class LaTeXHelpBuilder(LaTeXBuilder):
     name = 'mylatex'
 
@@ -19,8 +19,8 @@ class LaTeXHelpBuilder(LaTeXBuilder):
         self.info('Fixing Cyrillic characters...')
         tex = os.path.join(self.outdir, 'calibre.tex')
         with open(tex, 'r+b') as f:
-            raw = f.read()
-            for x in (b'Михаил Горбачёв', b'Фёдор Миха́йлович Достоевский'):
-                raw = raw.replace(x, br'{\fontencoding{T2A}\selectfont %s}' % (x.replace(b'а́', b'a')))
+            raw = f.read().decode('utf-8')
+            for x in (u'Михаил Горбачёв', u'Фёдор Миха́йлович Достоевский'):
+                raw = raw.replace(x, u'{\\fontencoding{T2A}\\selectfont %s}' % (x.replace(u'а́', u'a')))
             f.seek(0)
-            f.write(raw)
+            f.write(raw.encode('utf-8'))
